# Snake
The famous snake game built with python.

To install run the following onto the terminal:

`pip3 install snake-rogi.rib`

If you don't have already the pygame installed run:

`pip3 install pygame`

And finally, run the following to play the game:

`python3 -m snake-rogi`

The movement keys are "W", "A", "S" and "D", the "ESC" key is used to acess the game's menu
